## ----setup, include=F---------------------------------------------------------
knitr::opts_chunk$set(eval=TRUE)
devtools::load_all(".")

## ----start--------------------------------------------------------------------
library(ggseg)
library(magrittr)
library(dplyr)
library(ggplot2)
dkt

## -----------------------------------------------------------------------------
someData = tibble(area=c("superior temporal","pre central", "lateral orbitofrontal"),
                      p=c(.03,.6, .05)
                  )
someData

## -----------------------------------------------------------------------------
dkt %>% 
  left_join(someData) %>% 
  head(10) #only added to truncate output

## -----------------------------------------------------------------------------
dkt %>% 
  left_join(someData) %>% 
  arrange(p) %>% 
  head(10) #only added to truncate output

## -----------------------------------------------------------------------------
someData$hemi = rep("left", nrow(someData))
someData

dkt %>% 
  left_join(someData) %>% 
  arrange(p) %>% 
  head(10)

## -----------------------------------------------------------------------------
library(ggplot2)
ggseg(someData, atlas=dkt, mapping=aes(fill=p))

## -----------------------------------------------------------------------------
newAtlas = dkt %>% 
  left_join(someData)

ggseg(atlas=newAtlas, mapping=aes(fill=p), position="stacked")

## ----datasupp3----------------------------------------------------------------
someData = data.frame(
  area = rep(c("transverse temporal", "insula",
               "pre central","superior parietal"),2), 
  p = sample(seq(0,.5,.001), 8),
  AgeG = c(rep("Young",4), rep("Old",4)),
  stringsAsFactors = FALSE)
  
ggseg(.data=someData, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")


## ----duplicate----------------------------------------------------------------
# If you group_by the columns you will facet by, this will work well.
someData = someData %>% 
  group_by(AgeG)

# We can now supply the newAtlas as an atlas to ggseg
ggseg(.data = someData, atlas=dkt, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom") +
  scale_fill_gradientn(colours = c("royalblue","firebrick","goldenrod"),na.value="grey")

## ----duplicatepipe------------------------------------------------------------
someData %>% 
  group_by(AgeG) %>% 

  ggseg(atlas=dkt, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom") +
  scale_fill_gradientn(colours = c("royalblue","firebrick","goldenrod"),na.value="grey")

